@@ -4,7 +4,7 @@ from ZODB.DemoStorage import DemoStorage
 from ZODB.FileStorage import FileStorage
 from ZODB.MappingStorage import MappingStorage
 
-from .attributes.base import BaseAttribute, set_read_memoization
+from .attributes import Attribute, BaseAttribute, set_read_memoization
 from .attributes.blobs import Blob, BlobAttribute
 from .attributes.collections import (
     DictAttribute,
@@ -28,6 +28,7 @@ from .attributes.models import (
     InlineModelAttribute,
     IndexedModelAttribute,
 )
+from .attributes.password import PasswordAttribute
 from .attributes.simples import (
     BooleanAttribute,
     DateAttribute,
