@@ -4,7 +4,6 @@ import warnings
 import sheraf.exceptions
 from sheraf.models.base import BaseModel, BaseModelMetaclass
 from sheraf.models.indexmanager import (
-    IndexManager,
     SimpleIndexManager,
     MultipleDatabaseIndexManager,
 )
@@ -19,9 +18,10 @@ class BaseIndexedModelMetaclass(BaseModelMetaclass):
             # Get the real attributes objects when string have been passed as attributes
             # in the index.
 
+            index.key = index.key or name
             if not index.attributes:
                 raise sheraf.exceptions.SherafException(
-                    f"The {index.key} must have at least one attribute."
+                    f"The {index.key} index must have at least one attribute."
                 )
 
             new_attrs = []
@@ -33,7 +33,7 @@ class BaseIndexedModelMetaclass(BaseModelMetaclass):
                         raise sheraf.exceptions.SherafException(
                             f"The {index.key} index has a wrong attribute with name '{a}'."
                         )
-                if not isinstance(a, sheraf.BaseAttribute):
+                if not isinstance(a, sheraf.Attribute):
                     raise sheraf.exceptions.SherafException(
                         f"The {index.key} index has a wrong attribute."
                     )
@@ -41,19 +41,40 @@ class BaseIndexedModelMetaclass(BaseModelMetaclass):
                 new_attrs.append(a)
             index.attributes = new_attrs
 
-            index.attribute_values_func = {
-                attributes[k] if isinstance(k, str) else k: v
-                for k, v in index.attribute_values_func.items()
+            # Get the attributes from the attribute names
+            index.values_funcs = {
+                func: [
+                    [
+                        attributes[attr] if isinstance(attr, str) else attr
+                        for attr in attrs
+                    ]
+                    for attrs in attrs_groups
+                ]
+                for func, attrs_groups in index.values_funcs.items()
             }
 
-            index.key = index.key or name
-
             for attribute in index.attributes:
-
                 if add_to_attribute:
                     attribute.indexes[index.key] = index
 
                 attribute.lazy = False
+
+            # Assign the default values func to attributes without
+            # values func.
+            attrs_with_func = [
+                attr
+                for func, attr_groups in index.values_funcs.items()
+                if func is not index.default_values_func
+                for attrs in attr_groups
+                for attr in attrs
+            ]
+
+            index.values_funcs[index.default_values_func] = [
+                [attribute]
+                for attribute in index.attributes
+                if attribute not in attrs_with_func
+            ]
+
             klass.indexes[index.key] = klass.index_manager(index)
 
         for name, index in attrs.items():
@@ -94,7 +115,9 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
                 else:
                     raise sheraf.exceptions.PrimaryKeyException(
                         "A model can have only one primary key. '{}' has '{}' and '{}'".format(
-                            cls.__class__.__name__, cls._primary_key, index_name,
+                            cls.__class__.__name__,
+                            cls._primary_key,
+                            index_name,
                         )
                     )
 
@@ -522,8 +545,13 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
             attr.delete(self)
 
     @classmethod
-    def count(cls):
-        return cls.indexes[cls.primary_key()].count()
+    def count(cls, index_name=None):
+        """
+        Counts the number of elements in an index.
+        :param index_name: The name of the index to count. By default
+            the primary index is used
+        """
+        return cls.indexes[index_name or cls.primary_key()].count()
 
 
 class IndexedModelMetaclass(BaseIndexedModelMetaclass):
